==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/gl.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Xestionar Parámetros Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "xestionar arquivo");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Ancho da imaxe");
define('MANAGE_GALLERY_FULL_HEIGHT', "Imaxe a tamaño real Altura");
define('MANAGE_GALLERY_THUMB_WIDTH', "Ancho da imaxe en miniatura");
define('MANAGE_GALLERY_THUMB_HEIGHT', "miniatura Altura");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Preserve Aspect Ratio Thumb");
define('MANAGE_GALLERY_SHOW_TITLES', "amosar títulos");
define('MANAGE_GALLERY_DISABLE_SORT', "disable Sort");
define('MANAGE_GALLERY_DELETE_IMAGE', "eliminar imaxe");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Salva Orde de Clasificación");
define('MANAGE_GALLERY_PUBLISH_MSG', "Prema en &quot;Update&quot; para publicar <br /> súas imaxes cargadas.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Todas as imaxes foron redimensionadas e opcións foron gardadas.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Houbo un erro redimensionar as imaxes ou gardar a configuración.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "A súa imaxe (s) procede.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Houbo un erro ao enviar a túa foto (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "O ficheiro que cargou non é unha imaxe.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "O ficheiro que cargou é moi grande.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "O título foi gardado.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Está seguro de que quere borrar imaxe");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "A imaxe foi borrada.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Houbo un erro ao eliminar a imaxe.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Salvando parámetros e redimensionar imaxes, por favor espere ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Cargando, agarde por favor ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "A orde de clasificación non foi gardado. Quere gardar a orde de clasificación?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "A orde imaxe tipo foi gardado.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Houbo un erro ao gardar o tipo de imaxe.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/gl.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Xestionar Parámetros Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "xestionar arquivo");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Ancho da imaxe");
define('MANAGE_GALLERY_FULL_HEIGHT', "Imaxe a tamaño real Altura");
define('MANAGE_GALLERY_THUMB_WIDTH', "Ancho da imaxe en miniatura");
define('MANAGE_GALLERY_THUMB_HEIGHT', "miniatura Altura");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Preserve Aspect Ratio Thumb");
define('MANAGE_GALLERY_SHOW_TITLES', "amosar títulos");
define('MANAGE_GALLERY_DISABLE_SORT', "disable Sort");
define('MANAGE_GALLERY_DELETE_IMAGE', "eliminar imaxe");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Salva Orde de Clasificación");
define('MANAGE_GALLERY_PUBLISH_MSG', "Prema en &quot;Update&quot; para publicar <br /> súas imaxes cargadas.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Todas as imaxes foron redimensionadas e opcións foron gardadas.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Houbo un erro redimensionar as imaxes ou gardar a configuración.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "A súa imaxe (s) procede.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Houbo un erro ao enviar a túa foto (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "O ficheiro que cargou non é unha imaxe.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "O ficheiro que cargou é moi grande.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "O título foi gardado.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Está seguro de que quere borrar imaxe");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "A imaxe foi borrada.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Houbo un erro ao eliminar a imaxe.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Salvando parámetros e redimensionar imaxes, por favor espere ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Cargando, agarde por favor ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "A orde de clasificación non foi gardado. Quere gardar a orde de clasificación?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "A orde imaxe tipo foi gardado.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Houbo un erro ao gardar o tipo de imaxe.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "O ficheiro que estás a cargar é maior que a configuración PHP &quot;upload_max_filesize&quot; ou a &quot;post_max_size&quot;. Ponte en contacto co administrador do sistema para aumentar estes límites.");
?>
